@@ -66,11 +66,11 @@ void	  gdk_event_handler_set 	(GdkEventFunc    func,
 					 gpointer        data,
 					 GDestroyNotify  notify);
 
-void	  gdk_set_show_events		(gint		 show_events);
-void	  gdk_set_use_xshm		(gint		 use_xshm);
+void	  gdk_set_show_events		(gboolean	 show_events);
+void	  gdk_set_use_xshm		(gboolean	 use_xshm);
 
-gint	  gdk_get_show_events		(void);
-gint	  gdk_get_use_xshm		(void);
+gboolean  gdk_get_show_events		(void);
+gboolean  gdk_get_use_xshm		(void);
 gchar*	  gdk_get_display		(void);
 
 guint32 gdk_time_get	  (void);
@@ -90,20 +90,19 @@ gint gdk_input_add	  (gint		     source,
 			   gpointer	     data);
 void gdk_input_remove	  (gint		     tag);
 
-gint gdk_pointer_grab	(GdkWindow *	 window,
-			 gint		 owner_events,
-			 GdkEventMask	 event_mask,
-			 GdkWindow *	 confine_to,
-			 GdkCursor *	 cursor,
-			 guint32	 time);
-void gdk_pointer_ungrab (guint32	 time);
+gint     gdk_pointer_grab       (GdkWindow    *window,
+                                 gint          owner_events,
+                                 GdkEventMask  event_mask,
+                                 GdkWindow    *confine_to,
+                                 GdkCursor    *cursor,
+                                 guint32       time);
+void     gdk_pointer_ungrab     (guint32       time);
+gint     gdk_keyboard_grab      (GdkWindow    *window,
+                                 gboolean      owner_events,
+                                 guint32       time);
+void     gdk_keyboard_ungrab    (guint32       time);
+gboolean gdk_pointer_is_grabbed (void);
 
-gint gdk_keyboard_grab	 (GdkWindow *	  window,
-			  gint		  owner_events,
-			  guint32	  time);
-void gdk_keyboard_ungrab (guint32	  time);
-
-gint gdk_pointer_is_grabbed (void);
 
 gint gdk_screen_width  (void);
 gint gdk_screen_height (void);
@@ -300,8 +299,6 @@ void            gdk_drag_drop        (GdkDragContext *context,
 void            gdk_drag_abort       (GdkDragContext *context,
 				      guint32         time);
 
-GdkAtom       gdk_drag_get_selection (GdkDragContext *context);
-
 /* GdkWindow */
 
 void	      gdk_window_set_hints	 (GdkWindow	  *window,
@@ -328,7 +325,7 @@ void	      gdk_window_set_background	 (GdkWindow	  *window,
 					  GdkColor	  *color);
 void	      gdk_window_set_back_pixmap (GdkWindow	  *window,
 					  GdkPixmap	  *pixmap,
-					  gint		   parent_relative);
+					  gboolean         parent_relative);
 void	      gdk_window_set_cursor	 (GdkWindow	  *window,
 					  GdkCursor	  *cursor);
 void	      gdk_window_set_colormap	 (GdkWindow	  *window,
@@ -375,7 +372,7 @@ void	      gdk_window_set_icon	 (GdkWindow	  *window,
 					  GdkPixmap	  *pixmap,
 					  GdkBitmap	  *mask);
 void	      gdk_window_set_icon_name	 (GdkWindow	  *window, 
-					  gchar		  *name);
+					  const gchar	  *name);
 void	      gdk_window_set_group	 (GdkWindow	  *window, 
 					  GdkWindow	  *leader);
 void	      gdk_window_set_decorations (GdkWindow	  *window,
@@ -444,7 +441,7 @@ void   gdk_gc_set_clip_region	  (GdkGC	    *gc,
 void   gdk_gc_set_subwindow	  (GdkGC	    *gc,
 				   GdkSubwindowMode  mode);
 void   gdk_gc_set_exposures	  (GdkGC	    *gc,
-				   gint		     exposures);
+				   gboolean          exposures);
 void   gdk_gc_set_line_attributes (GdkGC	    *gc,
 				   gint		     line_width,
 				   GdkLineStyle	     line_style,
@@ -452,7 +449,7 @@ void   gdk_gc_set_line_attributes (GdkGC	    *gc,
 				   GdkJoinStyle	     join_style);
 void   gdk_gc_set_dashes          (GdkGC            *gc,
 				   gint	             dash_offset,
-				   gchar             dash_list[],
+				   gint8             dash_list[],
 				   gint              n);
 void   gdk_gc_copy		  (GdkGC	     *dst_gc,
 				   GdkGC	     *src_gc);
@@ -479,8 +476,8 @@ GdkPixmap* gdk_pixmap_create_from_xpm	(GdkWindow  *window,
 					 GdkBitmap **mask,
 					 GdkColor   *transparent_color,
 					 const gchar *filename);
-GdkPixmap* gdk_pixmap_colormap_create_from_xpm 
-                                        (GdkWindow   *window,
+GdkPixmap* gdk_pixmap_colormap_create_from_xpm (
+					 GdkWindow   *window,
 					 GdkColormap *colormap,
 					 GdkBitmap  **mask,
 					 GdkColor    *transparent_color,
@@ -489,8 +486,8 @@ GdkPixmap* gdk_pixmap_create_from_xpm_d (GdkWindow  *window,
 					 GdkBitmap **mask,
 					 GdkColor   *transparent_color,
 					 gchar	   **data);
-GdkPixmap* gdk_pixmap_colormap_create_from_xpm_d 
-                                        (GdkWindow   *window,
+GdkPixmap* gdk_pixmap_colormap_create_from_xpm_d (
+					 GdkWindow   *window,
 					 GdkColormap *colormap,
 					 GdkBitmap  **mask,
 					 GdkColor    *transparent_color,
@@ -529,77 +526,76 @@ void	   gdk_image_destroy   (GdkImage     *image);
 
 /* Color
  */
-GdkColormap* gdk_colormap_new	  (GdkVisual   *visual,
-				   gint		allocate);
-GdkColormap* gdk_colormap_ref	  (GdkColormap *cmap);
-void	     gdk_colormap_unref	  (GdkColormap *cmap);
+GdkColormap* gdk_colormap_new	          (GdkVisual      *visual,
+					   gboolean        allocate);
+GdkColormap* gdk_colormap_ref	          (GdkColormap    *cmap);
+void	     gdk_colormap_unref	          (GdkColormap    *cmap);
 
-GdkColormap* gdk_colormap_get_system	   (void);
-gint	     gdk_colormap_get_system_size  (void);
+GdkColormap* gdk_colormap_get_system	  (void);
+gint	     gdk_colormap_get_system_size (void);
 
-void gdk_colormap_change (GdkColormap	*colormap,
-			  gint		 ncolors);
+void         gdk_colormap_change          (GdkColormap    *colormap,
+					   gint		   ncolors);
 
+gint         gdk_colormap_alloc_colors    (GdkColormap    *colormap,
+					   GdkColor       *colors,
+					   gint            ncolors,
+					   gboolean        writeable,
+					   gboolean        best_match,
+					   gboolean       *success);
+gboolean     gdk_colormap_alloc_color     (GdkColormap    *colormap,
+					   GdkColor       *color,
+					   gboolean        writeable,
+					   gboolean        best_match);
+void         gdk_colormap_free_colors     (GdkColormap    *colormap,
+					   GdkColor       *colors,
+					   gint            ncolors);
 
-gint  gdk_colormap_alloc_colors   (GdkColormap *colormap,
-				   GdkColor    *colors,
-				   gint         ncolors,
-				   gboolean     writeable,
-				   gboolean     best_match,
-				   gboolean    *success);
-gboolean gdk_colormap_alloc_color (GdkColormap *colormap,
-				   GdkColor    *color,
-				   gboolean     writeable,
-				   gboolean     best_match);
-void     gdk_colormap_free_colors (GdkColormap *colormap,
-				   GdkColor    *colors,
-				   gint         ncolors);
+GdkVisual*   gdk_colormap_get_visual      (GdkColormap    *colormap);
 
-GdkVisual *gdk_colormap_get_visual (GdkColormap *colormap);
-     
-GdkColor *gdk_color_copy (GdkColor *color);
-void      gdk_color_free (GdkColor *color);
+GdkColor*    gdk_color_copy               (const GdkColor *color);
+void         gdk_color_free               (GdkColor       *color);
 
-gint gdk_color_parse	 (const gchar	*spec,
-			  GdkColor	*color);
-guint gdk_color_hash     (const GdkColor *colora,
-			  const GdkColor *colorb);
-gint gdk_color_equal	 (const GdkColor *colora,
-			  const GdkColor *colorb);
+gboolean     gdk_color_parse	          (const gchar    *spec,
+					   GdkColor       *color);
+guint        gdk_color_hash               (const GdkColor *colora,
+					   const GdkColor *colorb);
+gboolean     gdk_color_equal	          (const GdkColor *colora,
+					   const GdkColor *colorb);
 
 
 /* The following functions are deprecated */
-void gdk_colors_store	 (GdkColormap	*colormap,
-			  GdkColor	*colors,
-			  gint		 ncolors);
-gint gdk_colors_alloc	 (GdkColormap	*colormap,
-			  gint		 contiguous,
-			  gulong	*planes,
-			  gint		 nplanes,
-			  gulong	*pixels,
-			  gint		 npixels);
-void gdk_colors_free	 (GdkColormap	*colormap,
-			  gulong	*pixels,
-			  gint		 npixels,
-			  gulong	 planes);
-gint gdk_color_white	 (GdkColormap	*colormap,
-			  GdkColor	*color);
-gint gdk_color_black	 (GdkColormap	*colormap,
-			  GdkColor	*color);
-gint gdk_color_alloc	 (GdkColormap	*colormap,
-			  GdkColor	*color);
-gint gdk_color_change	 (GdkColormap	*colormap,
-			  GdkColor	*color);
+void     gdk_colors_store (GdkColormap	*colormap,
+			   GdkColor	*colors,
+			   gint		 ncolors);
+gboolean gdk_colors_alloc (GdkColormap	*colormap,
+			   gboolean      contiguous,
+			   gulong	*planes,
+			   gint		 nplanes,
+			   gulong	*pixels,
+			   gint		 npixels);
+void     gdk_colors_free  (GdkColormap	*colormap,
+			   gulong	*pixels,
+			   gint		 npixels,
+			   gulong	 planes);
+gboolean gdk_color_white  (GdkColormap	*colormap,
+			   GdkColor	*color);
+gboolean gdk_color_black  (GdkColormap	*colormap,
+			   GdkColor	*color);
+gboolean gdk_color_alloc  (GdkColormap	*colormap,
+			   GdkColor	*color);
+gboolean gdk_color_change (GdkColormap	*colormap,
+			   GdkColor	*color);
 
 
 /* Fonts
  */
 GdkFont* gdk_font_load	    (const gchar    *font_name);
-GdkFont* gdk_fontset_load   (gchar          *fontset_name);
+GdkFont* gdk_fontset_load   (const gchar    *fontset_name);
 GdkFont* gdk_font_ref	    (GdkFont        *font);
 void	 gdk_font_unref	    (GdkFont        *font);
 gint	 gdk_font_id	    (const GdkFont  *font);
-gint	 gdk_font_equal	    (const GdkFont  *fonta,
+gboolean gdk_font_equal	    (const GdkFont  *fonta,
 			     const GdkFont  *fontb);
 gint	 gdk_string_width   (GdkFont        *font,
 			     const gchar    *string);
@@ -750,7 +746,7 @@ void gdk_draw_lines      (GdkDrawable  *drawable,
 
 /* Selections
  */
-gint	   gdk_selection_owner_set (GdkWindow	 *owner,
+gboolean   gdk_selection_owner_set (GdkWindow	 *owner,
 				    GdkAtom	  selection,
 				    guint32	  time,
 				    gint	  send_event);
@@ -759,7 +755,7 @@ void	   gdk_selection_convert   (GdkWindow	 *requestor,
 				    GdkAtom	  selection,
 				    GdkAtom	  target,
 				    guint32	  time);
-gint	   gdk_selection_property_get (GdkWindow  *requestor,
+gboolean   gdk_selection_property_get (GdkWindow  *requestor,
 				       guchar	 **data,
 				       GdkAtom	  *prop_type,
 				       gint	  *prop_format);
@@ -769,89 +765,87 @@ void	   gdk_selection_send_notify (guint32	    requestor,
 				      GdkAtom	    property,
 				      guint32	    time);
 
-gint	   gdk_text_property_to_text_list (GdkAtom encoding, gint format,
+gint       gdk_text_property_to_text_list (GdkAtom encoding, gint format,
 					   guchar *text, gint length,
 					   gchar ***list);
 void	   gdk_free_text_list		  (gchar **list);
-gint	   gdk_string_to_compound_text	  (gchar *str,
+gint       gdk_string_to_compound_text	  (const gchar *str,
 					   GdkAtom *encoding, gint *format,
 					   guchar **ctext, gint *length);
 void	   gdk_free_compound_text	  (guchar *ctext);
 
 /* Properties
  */
-GdkAtom gdk_atom_intern	    (const gchar *atom_name,
-			     gint	  only_if_exists);
-gchar*	gdk_atom_name	    (GdkAtom atom);
-gint	gdk_property_get    (GdkWindow	 *window,
-			     GdkAtom	  property,
-			     GdkAtom	  type,
-			     gulong	  offset,
-			     gulong	  length,
-			     gint	  pdelete,
-			     GdkAtom	 *actual_property_type,
-			     gint	 *actual_format,
-			     gint	 *actual_length,
-			     guchar	**data);
+GdkAtom  gdk_atom_intern     (const gchar  *atom_name,
+                              gint          only_if_exists);
+gchar*   gdk_atom_name       (GdkAtom       atom);
+gboolean gdk_property_get    (GdkWindow    *window,
+                              GdkAtom       property,
+                              GdkAtom       type,
+                              gulong        offset,
+                              gulong        length,
+                              gint          pdelete,
+                              GdkAtom      *actual_property_type,
+                              gint         *actual_format,
+                              gint         *actual_length,
+                              guchar      **data);
+void     gdk_property_change (GdkWindow    *window,
+                              GdkAtom       property,
+                              GdkAtom       type,
+                              gint          format,
+                              GdkPropMode   mode,
+                              guchar       *data,
+                              gint          nelements);
+void     gdk_property_delete (GdkWindow    *window,
+                              GdkAtom       property);
 
-void	gdk_property_change (GdkWindow	 *window,
-			     GdkAtom	  property,
-			     GdkAtom	  type,
-			     gint	  format,
-			     GdkPropMode  mode,
-			     guchar	 *data,
-			     gint	  nelements);
-void	gdk_property_delete (GdkWindow	 *window,
-			     GdkAtom	  property);
 
 
 /* Rectangle utilities
  */
-gint gdk_rectangle_intersect (GdkRectangle *src1,
-			      GdkRectangle *src2,
-			      GdkRectangle *dest);
-void gdk_rectangle_union     (GdkRectangle *src1,
-			      GdkRectangle *src2,
-			      GdkRectangle *dest);
+gboolean gdk_rectangle_intersect (GdkRectangle *src1,
+                                  GdkRectangle *src2,
+                                  GdkRectangle *dest);
+void     gdk_rectangle_union     (GdkRectangle *src1,
+                                  GdkRectangle *src2,
+                                  GdkRectangle *dest);
 
 /* XInput support
  */
-
-void gdk_input_init			    (void);
-void gdk_input_exit			    (void);
-GList *gdk_input_list_devices		    (void);
-void gdk_input_set_extension_events	    (GdkWindow *window,
-					     gint mask,
-					     GdkExtensionMode mode);
-void gdk_input_set_source		    (guint32 deviceid,
-					     GdkInputSource source);
-gint gdk_input_set_mode			    (guint32 deviceid,
-					     GdkInputMode mode);
-void gdk_input_set_axes			    (guint32 deviceid,
-					     GdkAxisUse *axes);
-void gdk_input_set_key			    (guint32 deviceid,
-					     guint   index,
-					     guint   keyval,
-					     GdkModifierType modifiers);
-void gdk_input_window_get_pointer     (GdkWindow       *window,
-				       guint32	       deviceid,
-				       gdouble	       *x,
-				       gdouble	       *y,
-				       gdouble	       *pressure,
-				       gdouble	       *xtilt,
-				       gdouble	       *ytilt,
-				       GdkModifierType *mask);
-
-GdkTimeCoord *gdk_input_motion_events (GdkWindow *window,
-				       guint32 deviceid,
-				       guint32 start,
-				       guint32 stop,
-				       gint *nevents_return);
+void          gdk_input_init                 (void);
+void          gdk_input_exit                 (void);
+GList *       gdk_input_list_devices         (void);
+void          gdk_input_set_extension_events (GdkWindow        *window,
+                                              gint              mask,
+                                              GdkExtensionMode  mode);
+void          gdk_input_set_source           (guint32           deviceid,
+                                              GdkInputSource    source);
+gboolean      gdk_input_set_mode             (guint32           deviceid,
+                                              GdkInputMode      mode);
+void          gdk_input_set_axes             (guint32           deviceid,
+                                              GdkAxisUse       *axes);
+void          gdk_input_set_key              (guint32           deviceid,
+                                              guint             index,
+                                              guint             keyval,
+                                              GdkModifierType   modifiers);
+void          gdk_input_window_get_pointer   (GdkWindow        *window,
+                                              guint32           deviceid,
+                                              gdouble          *x,
+                                              gdouble          *y,
+                                              gdouble          *pressure,
+                                              gdouble          *xtilt,
+                                              gdouble          *ytilt,
+                                              GdkModifierType  *mask);
+GdkTimeCoord *gdk_input_motion_events        (GdkWindow        *window,
+                                              guint32           deviceid,
+                                              guint32           start,
+                                              guint32           stop,
+                                              gint             *nevents_return);
 
 /* International Input Method Support Functions
  */
 
-gint         gdk_im_ready	   (void);
+gboolean     gdk_im_ready	   (void);
 
 void         gdk_im_begin	   (GdkIC               *ic, 
 				    GdkWindow           *window);
