@@ -16,6 +16,14 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+
+/*
+ * Modified by the GTK+ Team and others 1997-1999.  See the AUTHORS
+ * file for a list of people on the GTK+ Team.  See the ChangeLog
+ * files for a list of changes.  These files are distributed with
+ * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
+ */
+
 #include <X11/Xlib.h>
 #include <X11/Xos.h>
 #include "gdk.h"
@@ -493,12 +501,14 @@ gdk_draw_lines (GdkDrawable *drawable,
   g_return_if_fail (gc != NULL);
 
   drawable_private = (GdkWindowPrivate*) drawable;
+  if (drawable_private->destroyed)
+    return;
   gc_private = (GdkGCPrivate*) gc;
 
   XDrawLines (drawable_private->xdisplay,
-            drawable_private->xwindow,
-            gc_private->xgc,
-            (XPoint *) points,
-            npoints,
-            CoordModeOrigin);
+	      drawable_private->xwindow,
+	      gc_private->xgc,
+	      (XPoint *) points,
+	      npoints,
+	      CoordModeOrigin);
 }
